@@ -58,8 +58,10 @@ function build_compileall {
 }
 
 function install_pre_deps {
+	# install python3 here to ensure same version
     pacman -S --needed --noconfirm p7zip git dos2unix rsync \
-        mingw-w64-"${ARCH}"-nsis wget intltool mingw-w64-"${ARCH}"-toolchain
+        mingw-w64-"${ARCH}"-nsis wget libopenssl intltool mingw-w64-"${ARCH}"-toolchain \
+        mingw-w64-"${ARCH}"-python3
 }
 
 function create_root {
@@ -82,13 +84,13 @@ function extract_installer {
 }
 
 PIP_REQUIREMENTS="\
-podcastparser==0.6.3
+podcastparser==0.6.4
 mygpoclient==1.8
-pywin32-ctypes==0.1.2
+git+https://github.com/enthought/pywin32-ctypes.git@f27d6a0
 html5lib==1.0.1
 webencodings==0.5.1
-six==1.11.0
-certifi==2018.4.16
+six==1.12.0
+certifi==2018.11.29
 "
 
 function install_deps {
@@ -113,7 +115,8 @@ function install_deps {
     # replace ca-certificates with certifi's
     build_pacman --noconfirm -Rdds mingw-w64-"${ARCH}"-ca-certificates || true
     mkdir -p ${MINGW_ROOT}/ssl
-    cp -v ${MINGW_ROOT}/lib/python3.6/site-packages/certifi/cacert.pem ${MINGW_ROOT}/ssl/cert.pem
+    site_packages=$(build_python -c  'import sys;print(next(c for c in sys.path if "site-packages" in c))')
+    cp -v ${site_packages}/certifi/cacert.pem ${MINGW_ROOT}/ssl/cert.pem
     build_pip uninstall -y certifi
 
     build_pacman --noconfirm -Rdds mingw-w64-"${ARCH}"-python3-pip || true
@@ -145,24 +148,30 @@ function install_gpodder {
     fi
 
     # Create launchers
+    echo "python3 is $(which python3) version is $(python3 --version)"
     python3 "${MISC}"/create-launcher.py \
         "${GPO_VERSION}" "${MINGW_ROOT}"/bin
 
 	# install fake dbus
-	rsync -arv --delete "${REPO_CLONE}"/tools/fake-dbus-module/dbus "${MINGW_ROOT}"/lib/python3.6/site-packages/
+    site_packages=$(build_python -c  'import sys;print(next(c for c in sys.path if "site-packages" in c))')
+    site_packages_unix=$(echo "/$site_packages" | sed -e 's/\\/\//g' -e 's/://')
+    rsync -arv --delete "${REPO_CLONE}"/tools/fake-dbus-module/dbus "${site_packages_unix}/"
 	
 	# install gtk3 settings for a proper font
 	mkdir -p "${MINGW_ROOT}"/etc/gtk-3.0
 	cp "${MISC}"/gtk3.0_settings.ini "${MINGW_ROOT}"/etc/gtk-3.0/settings.ini
 	
 	# install bin/gpodder bin/gpo to a separate package, to be run before gpodder/__init__.py
-	gpodder_launch_dir="${MINGW_ROOT}"/lib/python3.6/site-packages/gpodder_launch
+	gpodder_launch_dir="${site_packages_unix}"/gpodder_launch
 	mkdir -p "${gpodder_launch_dir}"
 	touch "${gpodder_launch_dir}"/__init__.py
 	cp ${REPO_CLONE}/bin/gpo "${gpodder_launch_dir}"/gpo.py
 	cp ${REPO_CLONE}/bin/gpodder "${gpodder_launch_dir}"/gpodder.py
 
     build_compileall -d "" -f -q "$(cygpath -w "${MINGW_ROOT}")"
+
+    # copy gpodder.ico for notification-win32
+    cp ${REPO_CLONE}/tools/win_installer/misc/gpodder.ico "${MINGW_ROOT}"/bin
 }
 
 function cleanup_before {
